# OpenNetics Lib

Python library made for the OpenNetics edge server development, to control and extend the
functionality of OpenNetics hardware with ease. Designed to offer an interactive interface.

## Installation & Usage

To install the library, use the following command:

```bash
pip install opennetics
```

Then import in server code with-

```py
import opennetics as on
```

### Find library documentation at: [link](https://github.com/OpenNetics/OpenNetics-py/wiki)

## Development Status

This library is currently under development. If you try it out and encounter any issues, please
submit them on this repository's issues page.

For any feedback or contributions, feel free to reach out!

